package com.ruoyi.project.training.elearn.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.training.elearn.domain.TElRecord;

/**
 * 岗位培训统计Mapper接口
 *
 * @author ssy
 * @date 2024-06-25
 */
public interface TElRecordMapper
{
    /**
     * 查询岗位培训统计
     *
     * @param id 岗位培训统计ID
     * @return 岗位培训统计
     */
    public TElRecord selectTElRecordById(Long id);

    /**
     * 查询岗位培训统计列表
     *
     * @param tElRecord 岗位培训统计
     * @return 岗位培训统计集合
     */
    @DataScope(deptAlias = "d")
    public List<TElRecord> selectTElRecordList(TElRecord tElRecord);

    /**
     * 新增岗位培训统计
     *
     * @param tElRecord 岗位培训统计
     * @return 结果
     */
    public int insertTElRecord(TElRecord tElRecord);

    /**
     * 修改岗位培训统计
     *
     * @param tElRecord 岗位培训统计
     * @return 结果
     */
    public int updateTElRecord(TElRecord tElRecord);

    /**
     * 删除岗位培训统计
     *
     * @param id 岗位培训统计ID
     * @return 结果
     */
    public int deleteTElRecordById(Long id);

    /**
     * 批量删除岗位培训统计
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTElRecordByIds(Long[] ids);

    List<String> queryNeedDeleteIds();

    List<String> queryNeedInsertIds();

    void deleteTElRecordByStaffId(String staffId);

    TElRecord queryQuData(Long id);

    TElRecord queryExamData(Long userId);
}
